; ##############################################################################
; ##############################################################################
; ##############################################################################
;																				
; Timer  berlauf-Int aktivieren (Timer/Counter Interrupt Mask)					
;																				
TIMER_AKTIVIEREN:
	ldi temp,(0<<OCIE2)|(0<<TOIE2)|(0<<TICIE1)|(0<<OCIE1A)|(0<<OCIE1B)|(0<<TOIE1)|(1<<TOIE0)
	out TIMSK,temp       
ret
; ##############################################################################
; ##############################################################################
; ##############################################################################
; TIMER0 (8Bit) Vorteiler														
;																				
; CS02 CS01 CS00 	Description													
;	0 	0 	0 		No clock source (Timer/Counter stopped).					
;	0 	0 	1 		clkI/O/		(No prescaling)									
;	0 	1 	0 		clkI/O/8 	(From prescaler)								
; 	0 	1 	1 		clkI/O/64 	(From prescaler)								
; 	1 	0 	0 		clkI/O/256 	(From prescaler)								
; 	1 	0 	1 		clkI/O/1024 (From prescaler)								
;	1 	1 	0 		External clock source on T0 pin. Clock on falling edge.		
;	1 	1 	1 		External clock source on T0 pin. Clock on rising edge.		
TIMER0_INITIALISIERUNG:
.equ TIMERWERT0	=256-20	;(2 hoch 8  minus...)		
	ldi temp,(1<<CS02)|(0<<CS01)|(0<<CS00)
	OUT TCCR0,temp

	ldi temp, TIMERWERT0	; TIMER0 Startwert		
	out TCNT0,temp
ret
; ##############################################################################
; ##############################################################################
; ##############################################################################
TIM0_OVF:
	GRUEN_OFF
	push TEMP		    	; Sichern von "TEMP" im Stack			
	in	 TEMP,SREG			; Einlesen des SREG 					
	push TEMP	    		; Schreiben von  SREG  im Stack (KOPIE)	
	push TEMP1
;-------------------------------------------------------------------------------
	ldi temp, TIMERWERT0	; TIMER0 Startwert						
	out TCNT0,temp
;-------------------------------------------------------------------------------
	LDS temp,(adr_DIGIT_NR)	; laden									
	cpi temp,0
	breq TIM0_DIGIT0		; vergleich								
	cpi temp,1
	breq TIM0_DIGIT1
	cpi temp,2
	breq TIM0_DIGIT2
	cpi temp,3
	breq TIM0_DIGIT3
	cpi temp,4
	breq TIM0_DIGIT4
	cpi temp,5
	breq TIM0_DIGIT5
	cpi temp,6
	breq TIM0_DIGIT6
	rjmp TIM0_DIGIT7
;-------------------------------------------------------------------------------
TIM0_DIGIT0:
	inc temp				; +1									
	STS(adr_DIGIT_NR),temp	; sichern								
	LDS temp,(adr_DIGIT0)
	rcall BALKEN_TEMP
	rcall DIGIT_0			; Digit ausgeben						
	rjmp TIM0_FERTIG
;-------------------------------------------------------------------------------
TIM0_DIGIT1:
	inc temp				; +1									
	STS(adr_DIGIT_NR),temp	; sichern								
	LDS temp,(adr_DIGIT1)	; laden									
	rcall BALKEN_TEMP		; Baken darstellen						
	rcall DIGIT_1			; Digit	darstellen						
	rjmp TIM0_FERTIG
;-------------------------------------------------------------------------------
TIM0_DIGIT2:
	inc temp				; +1									
	STS(adr_DIGIT_NR),temp	; sichern								
	LDS temp,(adr_DIGIT2)
	rcall BALKEN_TEMP
	rcall DIGIT_2
	rjmp TIM0_FERTIG
;-------------------------------------------------------------------------------
TIM0_DIGIT3:
	inc temp				; +1									
	STS(adr_DIGIT_NR),temp	; sichern								
	LDS temp,(adr_DIGIT3)
	rcall BALKEN_TEMP
	rcall DIGIT_3
	rjmp TIM0_FERTIG
;-------------------------------------------------------------------------------
TIM0_DIGIT4:
	inc temp				; +1									
	STS(adr_DIGIT_NR),temp	; sichern								
	LDS temp,(adr_DIGIT4)
	rcall BALKEN_TEMP
	rcall DIGIT_4
	rjmp TIM0_FERTIG
;-------------------------------------------------------------------------------
TIM0_DIGIT5:
	inc temp				; +1									
	STS(adr_DIGIT_NR),temp	; sichern								
	LDS temp,(adr_DIGIT5)
	rcall BALKEN_TEMP
	rcall DIGIT_5
	rjmp TIM0_FERTIG
;-------------------------------------------------------------------------------
TIM0_DIGIT6:
	inc temp				; +1									
	STS(adr_DIGIT_NR),temp	; sichern								
	LDS temp,(adr_DIGIT6)
	rcall BALKEN_TEMP
	rcall DIGIT_6
	rjmp TIM0_FERTIG
;-------------------------------------------------------------------------------
TIM0_DIGIT7:
	STS(adr_DIGIT_NR),NULL	; Null sichern							
	LDS temp,(adr_DIGIT7)
	rcall BALKEN_TEMP
	rcall DIGIT_7
	rjmp TIM0_FERTIG
;-------------------------------------------------------------------------------
;-------------------------------------------------------------------------------
TIM0_FERTIG:
	pop TEMP1
	pop	TEMP				; LESEN von SREG vom STACK (KOPIE)		
	out	SREG,TEMP			; Wiederherstellen von SREG				
	pop	TEMP				; Wiederherstellen von "TEMP" 			
	GRUEN_ON
reti
; ##############################################################################
; ##############################################################################
; ##############################################################################
BALKEN_TEMP:
;-------------------------------------------------------------------------------
; Punkt 			(L=on)														
	sbrc temp,7				; Skip if Bit in Register Cleared		
	DAT_L		
	sbrs temp,7				; Skip if Bit in Register is Set		
	DAT_H
	ENABLE
;-------------------------------------------------------------------------------
; g		 			(L=on)														
	sbrc temp,6				; Skip if Bit in Register Cleared		
	DAT_L		
	sbrs temp,6				; Skip if Bit in Register is Set		
	DAT_H
	ENABLE
;-------------------------------------------------------------------------------
; f		 			(L=on)														
	sbrc temp,5				; Skip if Bit in Register Cleared		
	DAT_L		
	sbrs temp,5				; Skip if Bit in Register is Set		
	DAT_H
	ENABLE
;-------------------------------------------------------------------------------
; e		 			(L=on)														
	sbrc temp,4				; Skip if Bit in Register Cleared		
	DAT_L		
	sbrs temp,4				; Skip if Bit in Register is Set		
	DAT_H
	ENABLE
;-------------------------------------------------------------------------------
; d		 			(L=on)														
	sbrc temp,3				; Skip if Bit in Register Cleared		
	DAT_L		
	sbrs temp,3				; Skip if Bit in Register is Set		
	DAT_H
	ENABLE
;-------------------------------------------------------------------------------
; c		 			(L=on)														
	sbrc temp,2				; Skip if Bit in Register Cleared		
	DAT_L		
	sbrs temp,2				; Skip if Bit in Register is Set		
	DAT_H
	ENABLE
;-------------------------------------------------------------------------------
; b		 			(L=on)														
	sbrc temp,1				; Skip if Bit in Register Cleared		
	DAT_L		
	sbrs temp,1				; Skip if Bit in Register is Set		
	DAT_H
	ENABLE
;-------------------------------------------------------------------------------
; a		 			(L=on)														
	sbrc temp,0				; Skip if Bit in Register Cleared		
	DAT_L		
	sbrs temp,0				; Skip if Bit in Register is Set		
	DAT_H
	ENABLE
ret
; ##############################################################################
; ##############################################################################
; ##############################################################################
; unten rechts																	
DIGIT_0:
	DAT_H		;*0 unten rechts	(H=on)
	ENABLE
	DAT_L		; 1					(H=on)
	ENABLE
	DAT_L		; 2					(H=on)
	ENABLE
	DAT_L		; 3 unten links		(H=on)
	ENABLE
	DAT_L		; 4 oben rechts		(H=on)
	ENABLE
	DAT_L		; 5					(H=on)
	ENABLE
	DAT_L		; 6					(H=on)
	ENABLE
	DAT_L		; 7 oben links		(H=on)
	ENABLE
ret
; ##############################################################################
; ##############################################################################
; ##############################################################################
DIGIT_1:
	DAT_L		; 0 unten rechts	(H=on)
	ENABLE
	DAT_H		;*1					(H=on)
	ENABLE
	DAT_L		; 2					(H=on)
	ENABLE
	DAT_L		; 3 unten links		(H=on)
	ENABLE
	DAT_L		; 4 oben rechts		(H=on)
	ENABLE
	DAT_L		; 5					(H=on)
	ENABLE
	DAT_L		; 6					(H=on)
	ENABLE
	DAT_L		; 7 oben links		(H=on)
	ENABLE
ret
; ##############################################################################
; ##############################################################################
; ##############################################################################
DIGIT_2:
	DAT_L		; 0 unten rechts	(H=on)
	ENABLE
	DAT_L		; 1					(H=on)
	ENABLE
	DAT_H		;*2					(H=on)
	ENABLE
	DAT_L		; 3 unten links		(H=on)
	ENABLE
	DAT_L		; 4 oben rechts		(H=on)
	ENABLE
	DAT_L		; 5					(H=on)
	ENABLE
	DAT_L		; 6					(H=on)
	ENABLE
	DAT_L		; 7 oben links		(H=on)
	ENABLE
ret
; ##############################################################################
; ##############################################################################
; ##############################################################################
DIGIT_3:
	DAT_L		; 0 unten rechts	(H=on)
	ENABLE
	DAT_L		; 1					(H=on)
	ENABLE
	DAT_L		; 2					(H=on)
	ENABLE
	DAT_H		;*3 unten links		(H=on)
	ENABLE
	DAT_L		; 4 oben rechts		(H=on)
	ENABLE
	DAT_L		; 5					(H=on)
	ENABLE
	DAT_L		; 6					(H=on)
	ENABLE
	DAT_L		; 7 oben links		(H=on)
	ENABLE
ret
; ##############################################################################
; ##############################################################################
; ##############################################################################
DIGIT_4:
	DAT_L		; 0 unten rechts	(H=on)
	ENABLE
	DAT_L		; 1					(H=on)
	ENABLE
	DAT_L		; 2					(H=on)
	ENABLE
	DAT_L		; 3 unten links		(H=on)
	ENABLE
	DAT_H		;*4 oben rechts		(H=on)
	ENABLE
	DAT_L		; 5					(H=on)
	ENABLE
	DAT_L		; 6					(H=on)
	ENABLE
	DAT_L		; 7 oben links		(H=on)
	ENABLE
ret
; ##############################################################################
; ##############################################################################
; ##############################################################################
DIGIT_5:
	DAT_L		; 0 unten rechts	(H=on)
	ENABLE
	DAT_L		; 1					(H=on)
	ENABLE
	DAT_L		; 2					(H=on)
	ENABLE
	DAT_L		; 3 unten links		(H=on)
	ENABLE
	DAT_L		; 4 oben rechts		(H=on)
	ENABLE
	DAT_H		;*5					(H=on)
	ENABLE
	DAT_L		; 6					(H=on)
	ENABLE
	DAT_L		; 7 oben links		(H=on)
	ENABLE
ret
; ##############################################################################
; ##############################################################################
; ##############################################################################
DIGIT_6:
	DAT_L		; 0 unten rechts	(H=on)
	ENABLE
	DAT_L		; 1					(H=on)
	ENABLE
	DAT_L		; 2					(H=on)
	ENABLE
	DAT_L		; 3 unten links		(H=on)
	ENABLE
	DAT_L		; 4 oben rechts		(H=on)
	ENABLE
	DAT_L		; 5					(H=on)
	ENABLE
	DAT_H		;*6					(H=on)
	ENABLE
	DAT_L		; 7 oben links		(H=on)
	ENABLE
ret
; ##############################################################################
; ##############################################################################
; ##############################################################################
DIGIT_7:
	DAT_L		; 0 unten rechts	(H=on)
	ENABLE
	DAT_H		; 1					(H=on)
	ENABLE
	DAT_L		; 2					(H=on)
	ENABLE
	DAT_L		; 3 unten links		(H=on)
	ENABLE
	DAT_L		; 4 oben rechts		(H=on)
	ENABLE
	DAT_L		; 5					(H=on)
	ENABLE
	DAT_L		; 6					(H=on)
	ENABLE
	DAT_H		; 7 oben links		(H=on)
	ENABLE
ret
; ##############################################################################
; ##############################################################################
; ##############################################################################






